summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qmenuitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qmenuitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qmenuitem_imp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/qtbindings/qmenuitem_imp.h b/kjsembed/qtbindings/qmenuitem_imp.h
index 3b1935d2..7af67bd6 100644
--- a/kjsembed/qtbindings/qmenuitem_imp.h
+++ b/kjsembed/qtbindings/qmenuitem_imp.h
@@ -17,7 +17,7 @@ class QMenuItem;
namespace KJSEmbed {
/**
* Wrapper class for QMenuItem methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static QMenuItem *toQMenuItem( KJS::Object &object );
+ static TQMenuItem *toQMenuItem( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -122,7 +122,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QMenuItem *instance; // Temp
+ TQMenuItem *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class QMenuItem;
namespace KJSEmbed {
/**
- * Wrapper class for QMenuItem methods.
+ * Wrapper class for TQMenuItem methods.
*
* @author Richard Moore, rich@kde.org